Tron
====

Tron is a centralized system for managing periodic batch processes
across a cluster. If this is your first time using Tron, read :doc:`tutorial`
and :doc:`overview` to get a better idea of what it is, how it works, and how
to use it.

.. note::

    Please report bugs in the documentation at `our Github issue tracker
    <http://www.github.com/yelp/Tron/issues>`_.

Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    whats-new.rst
    tutorial.rst
    overview.rst
    config.rst
    jobs.rst
    command_context.rst
    tronweb.rst
    tools.rst
    developing.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
